wick_import

Macro wick_import 

macro_rules! wick_import {
    () => { ... };
}
This macro is used to include the generated code from a wick-component-codegen build step.

Example


// Useful way of importing code and keeping it separate from your own code.
mod wick {
wick_import!();
}