macro_rules! binary_paired_right_stream {
($name:ident => $handler:ident) => { ... };
}Expand description
This macro will generate the implementations for binary operations that pair single packets with potential streams of packets.
A common example would be file system write() operations, where contents are paired with a filename and a stream of contents.